@@ -7,14 +7,14 @@ from orjson import JSONDecodeError, loads
 from pydantic.fields import SHAPE_LIST, SHAPE_SINGLETON
 from starlite_multipart.datastructures import UploadFile as MultipartUploadFile
 
-from starlite.datastructures import UploadFile
+from starlite.datastructures.upload_file import UploadFile
 from starlite.enums import RequestEncodingType
 
 if TYPE_CHECKING:
 
     from pydantic.fields import ModelField
 
-    from starlite.datastructures import FormMultiDict
+    from starlite.datastructures.form_multi_dict import FormMultiDict
 
 _true_values = {"True", "true"}
 _false_values = {"False", "false"}
@@ -75,6 +75,6 @@ def parse_form_data(media_type: "RequestEncodingType", form_data: "FormMultiDict
     if media_type == RequestEncodingType.MULTI_PART:
         if field.shape is SHAPE_LIST:
             return list(values_dict.values())
-        if field.shape is SHAPE_SINGLETON and field.type_ in [UploadFile, MultipartUploadFile] and values_dict:
+        if field.shape is SHAPE_SINGLETON and field.type_ in (UploadFile, MultipartUploadFile) and values_dict:
             return list(values_dict.values())[0]
     return values_dict
